@@ -1,8 +1,9 @@
 import re
+from typing import Optional
 
-from strictdoc.backend.dsl.models.document import Document
-from strictdoc.backend.dsl.models.requirement import Requirement
-from strictdoc.backend.dsl.models.section import Section
+from strictdoc.backend.sdoc.models.document import Document
+from strictdoc.backend.sdoc.models.requirement import Requirement
+from strictdoc.backend.sdoc.models.section import Section
 from strictdoc.core.finders.source_files_finder import SourceFile
 from strictdoc.export.html.document_type import DocumentType
 
@@ -37,28 +38,31 @@ class LinkRenderer:
         return local_anchor
 
     def render_requirement_link(
-        self, node, context_document, document_type: DocumentType
+        self,
+        node,
+        context_document: Optional[Document],
+        document_type: DocumentType,
     ):
-        assert isinstance(node, Requirement) or isinstance(node, Section)
+        assert isinstance(node, (Requirement, Section))
         assert isinstance(context_document, Document)
         assert isinstance(document_type, DocumentType)
         local_link = self.render_local_anchor(node)
-        if node.document == context_document:
+        if context_document and node.document == context_document:
             return f"#{local_link}"
+
+        link_cache_key = (document_type, context_document.meta.level)
+        if link_cache_key in self.req_link_cache:
+            document_type_cache = self.req_link_cache[link_cache_key]
+            if node in document_type_cache:
+                return document_type_cache[node]
         else:
-            link_cache_key = (document_type, context_document.meta.level)
-            if link_cache_key in self.req_link_cache:
-                document_type_cache = self.req_link_cache[link_cache_key]
-                if node in document_type_cache:
-                    return document_type_cache[node]
-            else:
-                self.req_link_cache[link_cache_key] = {}
-            document_link = node.document.meta.get_html_link(
-                document_type, context_document.meta.level
-            )
-            requirement_link = f"{document_link}#{local_link}"
-            self.req_link_cache[link_cache_key][node] = requirement_link
-            return requirement_link
+            self.req_link_cache[link_cache_key] = {}
+        document_link = node.document.meta.get_html_link(
+            document_type, context_document.meta.level
+        )
+        requirement_link = f"{document_link}#{local_link}"
+        self.req_link_cache[link_cache_key][node] = requirement_link
+        return requirement_link
 
     def render_requirement_link_from_source_file(self, node, source_file):
         assert isinstance(node, Requirement)
@@ -162,7 +166,7 @@ class LinkRenderer:
         req_uid: str,
         source_link: str,
         context_source_file: SourceFile,
-        range,
+        source_range,
     ):
         assert isinstance(source_link, str)
         assert len(source_link) > 0
@@ -178,7 +182,9 @@ class LinkRenderer:
             f"/_source_files"
             f"/{context_source_file.doctree_root_mount_path}"
             f"/{source_link}.html"
-            f"#{req_uid}#{range.ng_range_line_begin}#{range.ng_range_line_end}"
+            f"#{req_uid}"
+            f"#{source_range.ng_range_line_begin}"
+            f"#{source_range.ng_range_line_end}"
         )
         return source_file_link
 
@@ -187,10 +193,10 @@ class LinkRenderer:
         requirement: Requirement,
         source_link: str,
         context_source_file: SourceFile,
-        range,
+        source_range,
     ):
         return self.render_requirement_in_source_file_range_link_using_id(
-            requirement.uid, source_link, context_source_file, range
+            requirement.uid, source_link, context_source_file, source_range
         )
 
     @staticmethod
